##
##  wslay.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2020 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         wslay
Summary:      WebSocket Library
URL:          http://wslay.sourceforge.net/
Vendor:       Tatsuhiro Tsujikawa
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Web
License:      MIT
Version:      1.1.1
Release:      20200623

#   list of sources
Source0:      https://github.com/tatsuhiro-t/wslay/archive/release-%{version}.tar.gz
Patch0:       wslay.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, automake, autoconf, libtool
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Wslay is a WebSocket library written in C. It implements the
    protocol version 13 described in RFC 6455. This library offers 2
    levels of API: event-based API and frame-based low-level API. For
    event-based API, it is suitable for non-blocking reactor pattern
    style. You can set callbacks in various events. For frame-based API,
    you can send WebSocket frame directly. Wslay only supports data
    transfer part of WebSocket protocol and does not perform opening
    handshake in HTTP.

%track
    prog wslay = {
        version   = %{version}
        url       = https://github.com/tatsuhiro-t/wslay/releases
        regex     = release-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n wslay-release-%{version}
    %patch -p0

%build
    aclocal
    autoheader
    libtoolize
    automake --add-missing --copy
    autoconf
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

